@@ -20,6 +20,7 @@ describe 'keystone::cache' do
         is_expected.to contain_oslo__cache('keystone_config').with(
           :config_prefix                        => '<SERVICE DEFAULT>',
           :expiration_time                      => '<SERVICE DEFAULT>',
+          :backend_expiration_time              => '<SERVICE DEFAULT>',
           :backend                              => '<SERVICE DEFAULT>',
           :backend_argument                     => '<SERVICE DEFAULT>',
           :proxies                              => '<SERVICE DEFAULT>',
@@ -66,6 +67,7 @@ describe 'keystone::cache' do
         {
           :config_prefix                        => 'prefix',
           :expiration_time                      => 3600,
+          :backend_expiration_time              => 7200,
           :backend                              => 'oslo_cache.memcache_pool',
           :proxies                              => ['proxy01:8888', 'proxy02:8888'],
           :enabled                              => true,
@@ -118,6 +120,7 @@ describe 'keystone::cache' do
         is_expected.to contain_oslo__cache('keystone_config').with(
           :config_prefix                        => 'prefix',
           :expiration_time                      => 3600,
+          :backend_expiration_time              => 7200,
           :backend                              => 'oslo_cache.memcache_pool',
           :backend_argument                     => '<SERVICE DEFAULT>',
           :proxies                              => ['proxy01:8888', 'proxy02:8888'],
