@@ -28,10 +28,13 @@ describe 'keystone::federation::identity_provider' do
 
   shared_examples 'keystone::federation::identity_provider' do
     let :pre_condition do
-      "include apache
-       class { 'keystone':
-         service_name => 'httpd',
-       }"
+      <<-EOS
+      include apache
+      class { 'keystone':
+        service_name => 'httpd',
+      }
+      include keystone::wsgi::apache
+EOS
     end
 
     context 'with required params' do
@@ -55,7 +58,7 @@ describe 'keystone::federation::identity_provider' do
       )}
 
       it { is_expected.to contain_file("#{params[:idp_metadata_path]}").with(
-        :ensure => 'present',
+        :ensure => 'file',
         :mode   => '0600',
         :owner  => 'keystone',
       )}
@@ -95,9 +98,7 @@ describe 'keystone::federation::identity_provider' do
 
   shared_examples 'keystone::federation::identity_provider without Apache' do
     let :pre_condition do
-      "class { 'keystone':
-         service_name => '#{platform_params[:keystone_service]}',
-       }"
+      'include keystone'
     end
 
     context 'with default parameters' do
@@ -113,22 +114,10 @@ describe 'keystone::federation::identity_provider' do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      let (:platform_params) do
-        if facts[:os]['family'] == 'RedHat'
-          keystone_service = 'openstack-keystone'
-          python_pysaml2_package_name = 'python3-pysaml2'
-        else
-          keystone_service = 'keystone'
-          python_pysaml2_package_name = 'python3-pysaml2'
-        end
-        {
-          :keystone_service            => keystone_service,
-          :python_pysaml2_package_name => python_pysaml2_package_name
-        }
-      end
-
       it_behaves_like 'keystone::federation::identity_provider'
-      it_behaves_like 'keystone::federation::identity_provider without Apache'
+      if facts[:os]['name'] == 'Debian'
+        it_behaves_like 'keystone::federation::identity_provider without Apache'
+      end
     end
   end
 end
