@@ -8,8 +8,10 @@ describe 'keystone::federation::openidc' do
 
   let(:pre_condition) do
     <<-EOS
-    class { 'keystone': }
-
+    include apache
+    class { 'keystone':
+      service_name => 'httpd',
+    }
     include keystone::wsgi::apache
     EOS
   end
@@ -88,13 +90,40 @@ describe 'keystone::federation::openidc' do
 
       it 'should contain expected config' do
         content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
+        expect(content).to match('OIDCResponseType "id_token"')
+        expect(content).to match('OIDCScope "openid email profile"')
         expect(content).to match('OIDCClientID "openid_client_id"')
         expect(content).to match('OIDCClientSecret "openid_client_secret"')
+        expect(content).to match('OIDCCryptoPassphrase "openstack"')
         expect(content).to match('OIDCRedirectURI "http://localhost:5000/v3/redirect_uri"')
         expect(content).to match('OIDCProviderMetadataURL "https://accounts.google.com/.well-known/openid-configuration"')
       end
     end
 
+    context 'with openidc_crypto_passphrase' do
+      before do
+        params.merge!({
+          :openidc_crypto_passphrase => 'custompass'
+        })
+      end
+      it 'should contain the expected OIDCCryptoPassphrase' do
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
+        expect(content).to match('OIDCCryptoPassphrase "custompass"')
+      end
+    end
+
+    context 'with openidc_crypto_passphrase (array)' do
+      before do
+        params.merge!({
+          :openidc_crypto_passphrase => ['currentpass', 'oldpass']
+        })
+      end
+      it 'should contain the expected OIDCCryptoPassphrase' do
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
+        expect(content).to match('OIDCCryptoPassphrase "currentpass" "oldpass"')
+      end
+    end
+
     context 'with openidc_metadata_dir' do
       before do
         params.delete(:openidc_provider_metadata_url)
@@ -184,6 +213,18 @@ describe 'keystone::federation::openidc' do
       end
     end
 
+    context 'with additional openidc scope' do
+      before do
+        params.merge!({
+          :openidc_scope => ['iam', 'openid', 'email', 'profile'],
+        })
+      end
+      it 'should use the specified OIDCScope' do
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
+        expect(content).to match('OIDCScope "iam openid email profile"')
+      end
+    end
+
     context 'with memcache options' do
       before do
         params.merge!({
