@@ -6,11 +6,14 @@ describe 'keystone::ldap_backend' do
     context 'Using Default domain' do
       let(:title) { 'Default' }
       let(:pre_condition) do
-        <<-EOM
+        <<-EOS
+        include apache
         class { 'keystone':
+          service_name        => 'httpd',
           using_domain_config => true
         }
-        EOM
+        include keystone::wsgi::apache
+EOS
       end
 
       context 'with basic params' do
@@ -56,6 +59,7 @@ describe 'keystone::ldap_backend' do
             :tls_cacertfile                       => '/etc/ssl/certs/ca-certificates.crt',
             :tls_req_cert                         => 'demand',
             :identity_driver                      => 'ldap',
+            :connection_timeout                   => 111,
             :use_pool                             => 'True',
             :pool_size                            => 20,
             :pool_retry_max                       => 2,
@@ -73,6 +77,14 @@ describe 'keystone::ldap_backend' do
             :name => platform_params[:python_ldappool_package_name],
           )
         }
+        it 'should prepare the config file' do
+          is_expected.to contain_file('/etc/keystone/domains/keystone.Default.conf').with(
+            :ensure => 'file',
+            :mode   => '0640',
+            :owner  => 'root',
+            :group  => 'keystone'
+          )
+        end
         it 'should have basic params' do
           # basic params
           is_expected.to contain_keystone_domain_config('Default::ldap/url').with_value('ldap://foo')
@@ -124,6 +136,8 @@ describe 'keystone::ldap_backend' do
           is_expected.to contain_keystone_domain_config('Default::ldap/tls_cacertfile').with_value('/etc/ssl/certs/ca-certificates.crt')
           is_expected.to contain_keystone_domain_config('Default::ldap/tls_req_cert').with_value('demand')
 
+          is_expected.to contain_keystone_domain_config('Default::ldap/connection_timeout').with_value('111')
+
           # ldap pooling
           is_expected.to contain_keystone_domain_config('Default::ldap/use_pool').with_value('True')
           is_expected.to contain_keystone_domain_config('Default::ldap/pool_size').with_value('20')
@@ -164,11 +178,14 @@ describe 'keystone::ldap_backend' do
         }
       end
       let(:pre_condition) do
-        <<-EOM
+        <<EOS
+        include apache
         class { 'keystone':
+          service_name        => 'httpd',
           using_domain_config => true
         }
-        EOM
+        include keystone::wsgi::apache
+EOS
       end
       it 'should use the domain from the title' do
         is_expected.to contain_keystone_domain_config('foobar::ldap/url').with_value('ldap://foo')
@@ -176,17 +193,19 @@ describe 'keystone::ldap_backend' do
       end
     end
 
-    context 'checks' do
+    context 'with domain specific drivers disabled' do
       let(:title) { 'domain' }
-      context 'with domain specific drivers disabled' do
-        let(:pre_condition) do
-        <<-EOM
-        class { 'keystone': }
-        EOM
-        end
-
-        it { should raise_error(Puppet::Error) }
+      let(:pre_condition) do
+        <<-EOS
+        include apache
+        class { 'keystone':
+          service_name => 'httpd',
+        }
+        include keystone::wsgi::apache
+EOS
       end
+
+      it { should raise_error(Puppet::Error) }
     end
   end
 
