@@ -6,8 +6,7 @@ describe 'keystone::resource::authtoken' do
 
   let :params do
     { :username     => 'keystone',
-      :password     => 'secret',
-      :auth_url     => 'http://127.0.0.1:5000' }
+      :password     => 'secret' }
   end
 
   shared_examples 'shared examples' do
@@ -15,7 +14,7 @@ describe 'keystone::resource::authtoken' do
       it 'configures keystone authtoken' do
         is_expected.to contain_keystone_config('keystone_authtoken/username').with_value('keystone')
         is_expected.to contain_keystone_config('keystone_authtoken/password').with_value('secret').with_secret(true)
-        is_expected.to contain_keystone_config('keystone_authtoken/auth_url').with_value( params[:auth_url] )
+        is_expected.to contain_keystone_config('keystone_authtoken/auth_url').with_value('http://127.0.0.1:5000')
         is_expected.to contain_keystone_config('keystone_authtoken/project_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/project_domain_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('keystone_authtoken/system_scope').with_value('<SERVICE DEFAULT>')
@@ -88,7 +87,7 @@ describe 'keystone::resource::authtoken' do
       it 'override keystone authtoken parameters' do
         is_expected.to contain_keystone_config('keystone_authtoken/username').with_value(params[:username])
         is_expected.to contain_keystone_config('keystone_authtoken/password').with_value(params[:password]).with_secret(true)
-        is_expected.to contain_keystone_config('keystone_authtoken/auth_url').with_value( params[:auth_url] )
+        is_expected.to contain_keystone_config('keystone_authtoken/auth_url').with_value(params[:auth_url])
         is_expected.to contain_keystone_config('keystone_authtoken/project_name').with_value( params[:project_name] )
         is_expected.to contain_keystone_config('keystone_authtoken/user_domain_name').with_value(params[:user_domain_name])
         is_expected.to contain_keystone_config('keystone_authtoken/project_domain_name').with_value(params[:project_domain_name])
@@ -140,10 +139,10 @@ describe 'keystone::resource::authtoken' do
     end
 
     context 'without password required parameter' do
-      let :params do
+      before do
         params.delete(:password)
       end
-      it { expect { is_expected.to raise_error(Puppet::Error) } }
+      it { is_expected.to raise_error(Puppet::Error) }
     end
 
     context 'when specifying all memcache params' do
@@ -221,7 +220,7 @@ describe 'keystone::resource::authtoken' do
       before do
         params.merge!({ :memcache_security_strategy => 'mystrategy', })
       end
-      it { expect { is_expected.to raise_error(Puppet::Error, 'memcache_security_strategy can be set only to MAC or ENCRYPT') } }
+      it { is_expected.to raise_error(Puppet::Error, /memcache_security_strategy can be set only to None, MAC or ENCRYPT/) }
     end
 
     context 'memcache_security_strategy in lower case' do
@@ -234,14 +233,14 @@ describe 'keystone::resource::authtoken' do
       it { is_expected.to contain_keystone_config('keystone_authtoken/memcache_security_strategy').with_value( params[:memcache_security_strategy] ) }
     end
 
-    context 'require memcache_secret_key when memcache_security_strategy is defined' do
+    context 'require memcache_secret_key when memcache_security_strategy is not None' do
       before do
         params.merge!({
           :memcache_security_strategy => 'MAC',
           :memcache_secret_key        => '<SERVICE DEFAULT>',
         })
       end
-      it { expect { is_expected.to raise_error(Puppet::Error, 'memcache_secret_key is required when memcache_security_strategy is defined') } }
+      it { is_expected.to raise_error(Puppet::Error, /memcache_secret_key is required when memcache_security_strategy is not None/) }
     end
 
     context 'memcache_security_strategy is None' do
